Using gcmap instead of shadow frame.

Fix misuse of TBAAJRuntime & TBAARuntimeInfo. Now, the TBAAJRuntime is
only for runtime support function.

Update DexPC before lock object and suspend.

Change-Id: I40fa37f4863fe6e127328a8413285ee3c62e8505
diff --git a/src/thread.h b/src/thread.h
index 8b9c81d..7bd64c8 100644
--- a/src/thread.h
+++ b/src/thread.h
@@ -524,17 +524,17 @@
                         ManagedStack::TopShadowFrameOffset());
   }
 
-  // Number of references allocated in ShadowFrames on this thread
-  size_t NumShadowFrameReferences() const {
-    return managed_stack_.NumShadowFrameReferences();
+  // Number of references allocated in JNI ShadowFrames on this thread
+  size_t NumJniShadowFrameReferences() const {
+    return managed_stack_.NumJniShadowFrameReferences();
   }
 
   // Number of references in SIRTs on this thread
   size_t NumSirtReferences();
 
   // Number of references allocated in SIRTs & shadow frames on this thread
   size_t NumStackReferences() {
-    return NumSirtReferences() + NumShadowFrameReferences();
+    return NumSirtReferences() + NumJniShadowFrameReferences();
   };
 
   // Is the given obj in this thread's stack indirect reference table?
@@ -524,17 +524,17 @@
   size_t NumSirtReferences();
 
-  // Number of references allocated in SIRTs & shadow frames on this thread
+  // Number of references allocated in SIRTs & JNI shadow frames on this thread
   size_t NumStackReferences() {